description
======
------

什么是mumuzi
------
套娃之神mumuzi，在misc题基础上创造性地融入了围棋和套娃元素，开创了musc新分类，他出的题被亲切地称为“一题顶过去五题”，做完之后腰酸了，背疼了，跳楼也有劲了。


更新记录
=======
-------
v0.0.1 beta版本。

v0.1.0 更新txt文档的套娃功能。

v0.1.1 更新套神必须先说话再套娃的功能。

v0.1.2 更新套神语录。

v0.1.3 更新txt文档的解套功能；更新压缩文件的加套功能；拆分套神语录。

v0.1.4 更新txt文档的加套解套功能，去除效率极低的base92和hex。

v1.0.0 更新套神说话时添加分隔符；更新了套题算法并去掉了效率低下的套题算法。删除了不能解题的解题功能，目前正式发布mumuzi的套娃姬版本，版本号为v1.0.0。

v1.0.1 更新zip加密算法；添加了套神口算md5的技能。

v1.0.2 更新了help()函数，现在可以用mumuzi.help()来查看功能了。修复套娃函数只能套一层的奇怪bug。

v1.0.3 更新了套神夸人的功能，修改口算md5，有一定概率失败，这边建议您抽卡。

v1.0.4 更新启动界面。

v1.1.0 解题姬正式上线，更新了套神的解题功能，但是给不给你解要看套神的心情。顺便修复口算md5的逻辑bug，并提高套神夸人概率，现在更容易获得套神的夸奖了。

v1.1.1 修复部分bug。

v1.1.2 根据热心群友的建议，优化部分交互文本。

v1.1.3 更新了套神的笔算BTC的技能，有一定概率失败，这边建议您抽卡。

v1.1.4 更新了套神的手撸算式的技能，有一定概率失败，这边建议您抽卡。另外现在可以封套神的号了，如果你有管理员的身份，现在可以ban掉套神了，不过又有谁舍得ban掉套套子呢?

v1.1.5 考虑到套神实际的计算能力，适当提升了套神手撸算式算法的真实性。

v1.2.0 套神解封，喜大普奔，恭迎套神归位！！！此为ctfshow红包题，是个梗题，上班摸鱼的时候写的，所以代码丑陋，各位大师傅轻喷。现在国庆已过，上线真正能解题的版本。

v1.2.1 套神太炫了！！！！！

v1.2.2 套神更炫了！！！！！！！！！！但是请你不要再黑我电脑了好不好，网费不够用了！！！！！！！！！！

v1.2.3 套宝~嘿嘿~我的套宝~嘿嘿